# Release vX.Y.Z - [發佈標題]

## 🌟 亮點
本次發佈主要變更的簡要摘要。

## ✨ 新功能
- 🆕 **功能名稱**: 新功能的描述
- 🎨 **界面增強**: 介面改進的描述

## 🐛 錯誤修復
- 🔧 **問題修復**: 修復內容的描述 (fixes #issue_number)
- 🛡️ **安全修復**: 安全相關的改進

## 🚀 改進功能
- ⚡ **效能優化**: 效能最佳化
- 📱 **用戶體驗增強**: 用戶體驗改進

## 🔄 變更
- 🔀 **重大變更**: 任何重大變更（僅限主要版本）
- 📝 **文檔更新**: 文檔更新

---
**說明**: 此模板應該適應每種語言（CHANGELOG.en.md, CHANGELOG.zh-TW.md, CHANGELOG.zh-CN.md）
**注意**: 版本發佈文件不包含安裝與相關連結部分，這些內容已移至各語言的完整 CHANGELOG 文件中
